"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import tendermint.types.types_pb2
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BondStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BondStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BondStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BOND_STATUS_UNSPECIFIED: _BondStatus.ValueType  # 0
    """UNSPECIFIED defines an invalid validator status."""
    BOND_STATUS_UNBONDED: _BondStatus.ValueType  # 1
    """UNBONDED defines a validator that is not bonded."""
    BOND_STATUS_UNBONDING: _BondStatus.ValueType  # 2
    """UNBONDING defines a validator that is unbonding."""
    BOND_STATUS_BONDED: _BondStatus.ValueType  # 3
    """BONDED defines a validator that is bonded."""

class BondStatus(_BondStatus, metaclass=_BondStatusEnumTypeWrapper):
    """BondStatus is the status of a validator."""

BOND_STATUS_UNSPECIFIED: BondStatus.ValueType  # 0
"""UNSPECIFIED defines an invalid validator status."""
BOND_STATUS_UNBONDED: BondStatus.ValueType  # 1
"""UNBONDED defines a validator that is not bonded."""
BOND_STATUS_UNBONDING: BondStatus.ValueType  # 2
"""UNBONDING defines a validator that is unbonding."""
BOND_STATUS_BONDED: BondStatus.ValueType  # 3
"""BONDED defines a validator that is bonded."""
global___BondStatus = BondStatus

@typing_extensions.final
class HistoricalInfo(google.protobuf.message.Message):
    """HistoricalInfo contains header and validator information for a given block.
    It is stored as part of staking module's state, which persists the `n` most
    recent HistoricalInfo
    (`n` is set by the staking module's `historical_entries` parameter).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_FIELD_NUMBER: builtins.int
    VALSET_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> tendermint.types.types_pb2.Header: ...
    @property
    def valset(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validator]: ...
    def __init__(
        self,
        *,
        header: tendermint.types.types_pb2.Header | None = ...,
        valset: collections.abc.Iterable[global___Validator] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header", b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["header", b"header", "valset", b"valset"]) -> None: ...

global___HistoricalInfo = HistoricalInfo

@typing_extensions.final
class CommissionRates(google.protobuf.message.Message):
    """CommissionRates defines the initial commission rates to be used for creating
    a validator.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RATE_FIELD_NUMBER: builtins.int
    MAX_RATE_FIELD_NUMBER: builtins.int
    MAX_CHANGE_RATE_FIELD_NUMBER: builtins.int
    rate: builtins.str
    """rate is the commission rate charged to delegators, as a fraction."""
    max_rate: builtins.str
    """max_rate defines the maximum commission rate which validator can ever charge, as a fraction."""
    max_change_rate: builtins.str
    """max_change_rate defines the maximum daily increase of the validator commission, as a fraction."""
    def __init__(
        self,
        *,
        rate: builtins.str = ...,
        max_rate: builtins.str = ...,
        max_change_rate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_change_rate", b"max_change_rate", "max_rate", b"max_rate", "rate", b"rate"]) -> None: ...

global___CommissionRates = CommissionRates

@typing_extensions.final
class Commission(google.protobuf.message.Message):
    """Commission defines commission parameters for a given validator."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMISSION_RATES_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    @property
    def commission_rates(self) -> global___CommissionRates:
        """commission_rates defines the initial commission rates to be used for creating a validator."""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """update_time is the last time the commission rate was changed."""
    def __init__(
        self,
        *,
        commission_rates: global___CommissionRates | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["commission_rates", b"commission_rates", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commission_rates", b"commission_rates", "update_time", b"update_time"]) -> None: ...

global___Commission = Commission

@typing_extensions.final
class Description(google.protobuf.message.Message):
    """Description defines a validator description."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONIKER_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    WEBSITE_FIELD_NUMBER: builtins.int
    SECURITY_CONTACT_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    moniker: builtins.str
    """moniker defines a human-readable name for the validator."""
    identity: builtins.str
    """identity defines an optional identity signature (ex. UPort or Keybase)."""
    website: builtins.str
    """website defines an optional website link."""
    security_contact: builtins.str
    """security_contact defines an optional email for security contact."""
    details: builtins.str
    """details define other optional details."""
    def __init__(
        self,
        *,
        moniker: builtins.str = ...,
        identity: builtins.str = ...,
        website: builtins.str = ...,
        security_contact: builtins.str = ...,
        details: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["details", b"details", "identity", b"identity", "moniker", b"moniker", "security_contact", b"security_contact", "website", b"website"]) -> None: ...

global___Description = Description

@typing_extensions.final
class Validator(google.protobuf.message.Message):
    """Validator defines a validator, together with the total amount of the
    Validator's bond shares and their exchange rate to coins. Slashing results in
    a decrease in the exchange rate, allowing correct calculation of future
    undelegations without iterating over delegators. When coins are delegated to
    this validator, the validator is credited with a delegation whose number of
    bond shares is based on the amount of coins delegated divided by the current
    exchange rate. Voting power can be calculated as total bonded shares
    multiplied by exchange rate.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATOR_ADDRESS_FIELD_NUMBER: builtins.int
    CONSENSUS_PUBKEY_FIELD_NUMBER: builtins.int
    JAILED_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TOKENS_FIELD_NUMBER: builtins.int
    DELEGATOR_SHARES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    UNBONDING_HEIGHT_FIELD_NUMBER: builtins.int
    UNBONDING_TIME_FIELD_NUMBER: builtins.int
    COMMISSION_FIELD_NUMBER: builtins.int
    MIN_SELF_DELEGATION_FIELD_NUMBER: builtins.int
    operator_address: builtins.str
    """operator_address defines the address of the validator's operator; bech encoded in JSON."""
    @property
    def consensus_pubkey(self) -> google.protobuf.any_pb2.Any:
        """consensus_pubkey is the consensus public key of the validator, as a Protobuf Any."""
    jailed: builtins.bool
    """jailed defined whether the validator has been jailed from bonded status or not."""
    status: global___BondStatus.ValueType
    """status is the validator status (bonded/unbonding/unbonded)."""
    tokens: builtins.str
    """tokens define the delegated tokens (incl. self-delegation)."""
    delegator_shares: builtins.str
    """delegator_shares defines total shares issued to a validator's delegators."""
    @property
    def description(self) -> global___Description:
        """description defines the description terms for the validator."""
    unbonding_height: builtins.int
    """unbonding_height defines, if unbonding, the height at which this validator has begun unbonding."""
    @property
    def unbonding_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """unbonding_time defines, if unbonding, the min time for the validator to complete unbonding."""
    @property
    def commission(self) -> global___Commission:
        """commission defines the commission parameters."""
    min_self_delegation: builtins.str
    """min_self_delegation is the validator's self declared minimum self delegation."""
    def __init__(
        self,
        *,
        operator_address: builtins.str = ...,
        consensus_pubkey: google.protobuf.any_pb2.Any | None = ...,
        jailed: builtins.bool = ...,
        status: global___BondStatus.ValueType = ...,
        tokens: builtins.str = ...,
        delegator_shares: builtins.str = ...,
        description: global___Description | None = ...,
        unbonding_height: builtins.int = ...,
        unbonding_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        commission: global___Commission | None = ...,
        min_self_delegation: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["commission", b"commission", "consensus_pubkey", b"consensus_pubkey", "description", b"description", "unbonding_time", b"unbonding_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commission", b"commission", "consensus_pubkey", b"consensus_pubkey", "delegator_shares", b"delegator_shares", "description", b"description", "jailed", b"jailed", "min_self_delegation", b"min_self_delegation", "operator_address", b"operator_address", "status", b"status", "tokens", b"tokens", "unbonding_height", b"unbonding_height", "unbonding_time", b"unbonding_time"]) -> None: ...

global___Validator = Validator

@typing_extensions.final
class ValAddresses(google.protobuf.message.Message):
    """ValAddresses defines a repeated set of validator addresses."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESSES_FIELD_NUMBER: builtins.int
    @property
    def addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        addresses: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["addresses", b"addresses"]) -> None: ...

global___ValAddresses = ValAddresses

@typing_extensions.final
class DVPair(google.protobuf.message.Message):
    """DVPair is struct that just has a delegator-validator pair with no other data.
    It is intended to be used as a marshalable pointer. For example, a DVPair can
    be used to construct the key to getting an UnbondingDelegation from state.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    validator_address: builtins.str
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "validator_address", b"validator_address"]) -> None: ...

global___DVPair = DVPair

@typing_extensions.final
class DVPairs(google.protobuf.message.Message):
    """DVPairs defines an array of DVPair objects."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAIRS_FIELD_NUMBER: builtins.int
    @property
    def pairs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DVPair]: ...
    def __init__(
        self,
        *,
        pairs: collections.abc.Iterable[global___DVPair] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pairs", b"pairs"]) -> None: ...

global___DVPairs = DVPairs

@typing_extensions.final
class DVVTriplet(google.protobuf.message.Message):
    """DVVTriplet is struct that just has a delegator-validator-validator triplet
    with no other data. It is intended to be used as a marshalable pointer. For
    example, a DVVTriplet can be used to construct the key to getting a
    Redelegation from state.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    validator_src_address: builtins.str
    validator_dst_address: builtins.str
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_src_address: builtins.str = ...,
        validator_dst_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "validator_dst_address", b"validator_dst_address", "validator_src_address", b"validator_src_address"]) -> None: ...

global___DVVTriplet = DVVTriplet

@typing_extensions.final
class DVVTriplets(google.protobuf.message.Message):
    """DVVTriplets defines an array of DVVTriplet objects."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIPLETS_FIELD_NUMBER: builtins.int
    @property
    def triplets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DVVTriplet]: ...
    def __init__(
        self,
        *,
        triplets: collections.abc.Iterable[global___DVVTriplet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["triplets", b"triplets"]) -> None: ...

global___DVVTriplets = DVVTriplets

@typing_extensions.final
class Delegation(google.protobuf.message.Message):
    """Delegation represents the bond with tokens held by an account. It is
    owned by one delegator, and is associated with the voting power of one
    validator.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    SHARES_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    """delegator_address is the bech32-encoded address of the delegator."""
    validator_address: builtins.str
    """validator_address is the bech32-encoded address of the validator."""
    shares: builtins.str
    """shares define the delegation shares received."""
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
        shares: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "shares", b"shares", "validator_address", b"validator_address"]) -> None: ...

global___Delegation = Delegation

@typing_extensions.final
class UnbondingDelegation(google.protobuf.message.Message):
    """UnbondingDelegation stores all of a single delegator's unbonding bonds
    for a single validator in an time-ordered list.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    """delegator_address is the bech32-encoded address of the delegator."""
    validator_address: builtins.str
    """validator_address is the bech32-encoded address of the validator."""
    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UnbondingDelegationEntry]:
        """entries are the unbonding delegation entries.
        unbonding delegation entries
        """
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
        entries: collections.abc.Iterable[global___UnbondingDelegationEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "entries", b"entries", "validator_address", b"validator_address"]) -> None: ...

global___UnbondingDelegation = UnbondingDelegation

@typing_extensions.final
class UnbondingDelegationEntry(google.protobuf.message.Message):
    """UnbondingDelegationEntry defines an unbonding object with relevant metadata."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_HEIGHT_FIELD_NUMBER: builtins.int
    COMPLETION_TIME_FIELD_NUMBER: builtins.int
    INITIAL_BALANCE_FIELD_NUMBER: builtins.int
    BALANCE_FIELD_NUMBER: builtins.int
    creation_height: builtins.int
    """creation_height is the height which the unbonding took place."""
    @property
    def completion_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """completion_time is the unix time for unbonding completion."""
    initial_balance: builtins.str
    """initial_balance defines the tokens initially scheduled to receive at completion."""
    balance: builtins.str
    """balance defines the tokens to receive at completion."""
    def __init__(
        self,
        *,
        creation_height: builtins.int = ...,
        completion_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        initial_balance: builtins.str = ...,
        balance: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["completion_time", b"completion_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balance", b"balance", "completion_time", b"completion_time", "creation_height", b"creation_height", "initial_balance", b"initial_balance"]) -> None: ...

global___UnbondingDelegationEntry = UnbondingDelegationEntry

@typing_extensions.final
class RedelegationEntry(google.protobuf.message.Message):
    """RedelegationEntry defines a redelegation object with relevant metadata."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_HEIGHT_FIELD_NUMBER: builtins.int
    COMPLETION_TIME_FIELD_NUMBER: builtins.int
    INITIAL_BALANCE_FIELD_NUMBER: builtins.int
    SHARES_DST_FIELD_NUMBER: builtins.int
    creation_height: builtins.int
    """creation_height  defines the height which the redelegation took place."""
    @property
    def completion_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """completion_time defines the unix time for redelegation completion."""
    initial_balance: builtins.str
    """initial_balance defines the initial balance when redelegation started."""
    shares_dst: builtins.str
    """shares_dst is the amount of destination-validator shares created by redelegation."""
    def __init__(
        self,
        *,
        creation_height: builtins.int = ...,
        completion_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        initial_balance: builtins.str = ...,
        shares_dst: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["completion_time", b"completion_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["completion_time", b"completion_time", "creation_height", b"creation_height", "initial_balance", b"initial_balance", "shares_dst", b"shares_dst"]) -> None: ...

global___RedelegationEntry = RedelegationEntry

@typing_extensions.final
class Redelegation(google.protobuf.message.Message):
    """Redelegation contains the list of a particular delegator's redelegating bonds
    from a particular source validator to a particular destination validator.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    """delegator_address is the bech32-encoded address of the delegator."""
    validator_src_address: builtins.str
    """validator_src_address is the validator redelegation source operator address."""
    validator_dst_address: builtins.str
    """validator_dst_address is the validator redelegation destination operator address."""
    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RedelegationEntry]:
        """entries are the redelegation entries.
        redelegation entries
        """
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_src_address: builtins.str = ...,
        validator_dst_address: builtins.str = ...,
        entries: collections.abc.Iterable[global___RedelegationEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "entries", b"entries", "validator_dst_address", b"validator_dst_address", "validator_src_address", b"validator_src_address"]) -> None: ...

global___Redelegation = Redelegation

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params defines the parameters for the staking module."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNBONDING_TIME_FIELD_NUMBER: builtins.int
    MAX_VALIDATORS_FIELD_NUMBER: builtins.int
    MAX_ENTRIES_FIELD_NUMBER: builtins.int
    HISTORICAL_ENTRIES_FIELD_NUMBER: builtins.int
    BOND_DENOM_FIELD_NUMBER: builtins.int
    MIN_COMMISSION_RATE_FIELD_NUMBER: builtins.int
    MIN_SELF_DELEGATION_FIELD_NUMBER: builtins.int
    @property
    def unbonding_time(self) -> google.protobuf.duration_pb2.Duration:
        """unbonding_time is the time duration of unbonding."""
    max_validators: builtins.int
    """max_validators is the maximum number of validators."""
    max_entries: builtins.int
    """max_entries is the max entries for either unbonding delegation or redelegation (per pair/trio)."""
    historical_entries: builtins.int
    """historical_entries is the number of historical entries to persist."""
    bond_denom: builtins.str
    """bond_denom defines the bondable coin denomination."""
    min_commission_rate: builtins.str
    """min_commission_rate is the chain-wide minimum commission rate that a validator can charge their delegators"""
    min_self_delegation: builtins.str
    """min_self_delegation is the chain-wide minimum amount that a validator has to self delegate"""
    def __init__(
        self,
        *,
        unbonding_time: google.protobuf.duration_pb2.Duration | None = ...,
        max_validators: builtins.int = ...,
        max_entries: builtins.int = ...,
        historical_entries: builtins.int = ...,
        bond_denom: builtins.str = ...,
        min_commission_rate: builtins.str = ...,
        min_self_delegation: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["unbonding_time", b"unbonding_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bond_denom", b"bond_denom", "historical_entries", b"historical_entries", "max_entries", b"max_entries", "max_validators", b"max_validators", "min_commission_rate", b"min_commission_rate", "min_self_delegation", b"min_self_delegation", "unbonding_time", b"unbonding_time"]) -> None: ...

global___Params = Params

@typing_extensions.final
class DelegationResponse(google.protobuf.message.Message):
    """DelegationResponse is equivalent to Delegation except that it contains a
    balance in addition to shares which is more suitable for client responses.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATION_FIELD_NUMBER: builtins.int
    BALANCE_FIELD_NUMBER: builtins.int
    @property
    def delegation(self) -> global___Delegation: ...
    @property
    def balance(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(
        self,
        *,
        delegation: global___Delegation | None = ...,
        balance: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["balance", b"balance", "delegation", b"delegation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balance", b"balance", "delegation", b"delegation"]) -> None: ...

global___DelegationResponse = DelegationResponse

@typing_extensions.final
class RedelegationEntryResponse(google.protobuf.message.Message):
    """RedelegationEntryResponse is equivalent to a RedelegationEntry except that it
    contains a balance in addition to shares which is more suitable for client
    responses.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDELEGATION_ENTRY_FIELD_NUMBER: builtins.int
    BALANCE_FIELD_NUMBER: builtins.int
    @property
    def redelegation_entry(self) -> global___RedelegationEntry: ...
    balance: builtins.str
    def __init__(
        self,
        *,
        redelegation_entry: global___RedelegationEntry | None = ...,
        balance: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["redelegation_entry", b"redelegation_entry"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balance", b"balance", "redelegation_entry", b"redelegation_entry"]) -> None: ...

global___RedelegationEntryResponse = RedelegationEntryResponse

@typing_extensions.final
class RedelegationResponse(google.protobuf.message.Message):
    """RedelegationResponse is equivalent to a Redelegation except that its entries
    contain a balance in addition to shares which is more suitable for client
    responses.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDELEGATION_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def redelegation(self) -> global___Redelegation: ...
    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RedelegationEntryResponse]: ...
    def __init__(
        self,
        *,
        redelegation: global___Redelegation | None = ...,
        entries: collections.abc.Iterable[global___RedelegationEntryResponse] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["redelegation", b"redelegation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entries", b"entries", "redelegation", b"redelegation"]) -> None: ...

global___RedelegationResponse = RedelegationResponse

@typing_extensions.final
class Pool(google.protobuf.message.Message):
    """Pool is used for tracking bonded and not-bonded token supply of the bond
    denomination.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOT_BONDED_TOKENS_FIELD_NUMBER: builtins.int
    BONDED_TOKENS_FIELD_NUMBER: builtins.int
    not_bonded_tokens: builtins.str
    bonded_tokens: builtins.str
    def __init__(
        self,
        *,
        not_bonded_tokens: builtins.str = ...,
        bonded_tokens: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bonded_tokens", b"bonded_tokens", "not_bonded_tokens", b"not_bonded_tokens"]) -> None: ...

global___Pool = Pool



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.gamm.pool_models.stableswap import tx_pb2 as osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2


class MsgStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateStableswapPool = channel.unary_unary(
                '/osmosis.gamm.poolmodels.stableswap.v1beta1.Msg/CreateStableswapPool',
                request_serializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPool.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPoolResponse.FromString,
                )
        self.StableSwapAdjustScalingFactors = channel.unary_unary(
                '/osmosis.gamm.poolmodels.stableswap.v1beta1.Msg/StableSwapAdjustScalingFactors',
                request_serializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactors.SerializeToString,
                response_deserializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactorsResponse.FromString,
                )


class MsgServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateStableswapPool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StableSwapAdjustScalingFactors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateStableswapPool': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStableswapPool,
                    request_deserializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPool.FromString,
                    response_serializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPoolResponse.SerializeToString,
            ),
            'StableSwapAdjustScalingFactors': grpc.unary_unary_rpc_method_handler(
                    servicer.StableSwapAdjustScalingFactors,
                    request_deserializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactors.FromString,
                    response_serializer=osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactorsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.gamm.poolmodels.stableswap.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateStableswapPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.poolmodels.stableswap.v1beta1.Msg/CreateStableswapPool',
            osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPool.SerializeToString,
            osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgCreateStableswapPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StableSwapAdjustScalingFactors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.gamm.poolmodels.stableswap.v1beta1.Msg/StableSwapAdjustScalingFactors',
            osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactors.SerializeToString,
            osmosis_dot_gamm_dot_pool__models_dot_stableswap_dot_tx__pb2.MsgStableSwapAdjustScalingFactorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/gamm/pool-models/stableswap/stableswap_pool.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9osmosis/gamm/pool-models/stableswap/stableswap_pool.proto\x12*osmosis.gamm.poolmodels.stableswap.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xb6\x01\n\nPoolParams\x12S\n\x08swap_fee\x18\x01 \x01(\tBA\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x0fyaml:\"swap_fee\"\xc8\xde\x1f\x00\x12S\n\x08\x65xit_fee\x18\x02 \x01(\tBA\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x0fyaml:\"exit_fee\"\xc8\xde\x1f\x00\"\xb9\x04\n\x04Pool\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12\n\n\x02id\x18\x02 \x01(\x04\x12r\n\x0bpool_params\x18\x03 \x01(\x0b\x32\x36.osmosis.gamm.poolmodels.stableswap.v1beta1.PoolParamsB%\xf2\xde\x1f\x1dyaml:\"stableswap_pool_params\"\xc8\xde\x1f\x00\x12=\n\x14\x66uture_pool_governor\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:\"future_pool_governor\"\x12L\n\x0ctotal_shares\x18\x05 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1b\xf2\xde\x1f\x13yaml:\"total_shares\"\xc8\xde\x1f\x00\x12\x63\n\x0epool_liquidity\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12>\n\x0fscaling_factors\x18\x07 \x03(\x04\x42%\xf2\xde\x1f!yaml:\"stableswap_scaling_factors\"\x12G\n\x19scaling_factor_controller\x18\x08 \x01(\tB$\xf2\xde\x1f yaml:\"scaling_factor_controller\":\x11\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xd2\xb4-\x05PoolIBCZAgithub.com/osmosis-labs/osmosis/v14/x/gamm/pool-models/stableswapb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.gamm.pool_models.stableswap.stableswap_pool_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZAgithub.com/osmosis-labs/osmosis/v14/x/gamm/pool-models/stableswap'
  _POOLPARAMS.fields_by_name['swap_fee']._options = None
  _POOLPARAMS.fields_by_name['swap_fee']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\017yaml:\"swap_fee\"\310\336\037\000'
  _POOLPARAMS.fields_by_name['exit_fee']._options = None
  _POOLPARAMS.fields_by_name['exit_fee']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\017yaml:\"exit_fee\"\310\336\037\000'
  _POOL.fields_by_name['address']._options = None
  _POOL.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _POOL.fields_by_name['pool_params']._options = None
  _POOL.fields_by_name['pool_params']._serialized_options = b'\362\336\037\035yaml:\"stableswap_pool_params\"\310\336\037\000'
  _POOL.fields_by_name['future_pool_governor']._options = None
  _POOL.fields_by_name['future_pool_governor']._serialized_options = b'\362\336\037\033yaml:\"future_pool_governor\"'
  _POOL.fields_by_name['total_shares']._options = None
  _POOL.fields_by_name['total_shares']._serialized_options = b'\362\336\037\023yaml:\"total_shares\"\310\336\037\000'
  _POOL.fields_by_name['pool_liquidity']._options = None
  _POOL.fields_by_name['pool_liquidity']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _POOL.fields_by_name['scaling_factors']._options = None
  _POOL.fields_by_name['scaling_factors']._serialized_options = b'\362\336\037!yaml:\"stableswap_scaling_factors\"'
  _POOL.fields_by_name['scaling_factor_controller']._options = None
  _POOL.fields_by_name['scaling_factor_controller']._serialized_options = b'\362\336\037 yaml:\"scaling_factor_controller\"'
  _POOL._options = None
  _POOL._serialized_options = b'\210\240\037\000\230\240\037\000\322\264-\005PoolI'
  _POOLPARAMS._serialized_start=284
  _POOLPARAMS._serialized_end=466
  _POOL._serialized_start=469
  _POOL._serialized_end=1038
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.bank.v1beta1.bank_pb2
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryBalanceRequest(google.protobuf.message.Message):
    """QueryBalanceRequest is the request type for the Query/Balance RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    DENOM_FIELD_NUMBER: builtins.int
    address: builtins.str
    """address is the address to query balances for."""
    denom: builtins.str
    """denom is the coin denom to query balances for."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "denom", b"denom"]) -> None: ...

global___QueryBalanceRequest = QueryBalanceRequest

@typing_extensions.final
class QueryBalanceResponse(google.protobuf.message.Message):
    """QueryBalanceResponse is the response type for the Query/Balance RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BALANCE_FIELD_NUMBER: builtins.int
    @property
    def balance(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """balance is the balance of the coin."""
    def __init__(
        self,
        *,
        balance: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["balance", b"balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balance", b"balance"]) -> None: ...

global___QueryBalanceResponse = QueryBalanceResponse

@typing_extensions.final
class QueryAllBalancesRequest(google.protobuf.message.Message):
    """QueryBalanceRequest is the request type for the Query/AllBalances RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    address: builtins.str
    """address is the address to query balances for."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "pagination", b"pagination"]) -> None: ...

global___QueryAllBalancesRequest = QueryAllBalancesRequest

@typing_extensions.final
class QueryAllBalancesResponse(google.protobuf.message.Message):
    """QueryAllBalancesResponse is the response type for the Query/AllBalances RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BALANCES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def balances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """balances is the balances of all the coins."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        balances: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balances", b"balances", "pagination", b"pagination"]) -> None: ...

global___QueryAllBalancesResponse = QueryAllBalancesResponse

@typing_extensions.final
class QueryTotalSupplyRequest(google.protobuf.message.Message):
    """QueryTotalSupplyRequest is the request type for the Query/TotalSupply RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request.

        Since: cosmos-sdk 0.43
        """
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___QueryTotalSupplyRequest = QueryTotalSupplyRequest

@typing_extensions.final
class QueryTotalSupplyResponse(google.protobuf.message.Message):
    """QueryTotalSupplyResponse is the response type for the Query/TotalSupply RPC
    method
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUPPLY_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def supply(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """supply is the supply of the coins"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response.

        Since: cosmos-sdk 0.43
        """
    def __init__(
        self,
        *,
        supply: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "supply", b"supply"]) -> None: ...

global___QueryTotalSupplyResponse = QueryTotalSupplyResponse

@typing_extensions.final
class QuerySupplyOfRequest(google.protobuf.message.Message):
    """QuerySupplyOfRequest is the request type for the Query/SupplyOf RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    denom: builtins.str
    """denom is the coin denom to query balances for."""
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom"]) -> None: ...

global___QuerySupplyOfRequest = QuerySupplyOfRequest

@typing_extensions.final
class QuerySupplyOfResponse(google.protobuf.message.Message):
    """QuerySupplyOfResponse is the response type for the Query/SupplyOf RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """amount is the supply of the coin."""
    def __init__(
        self,
        *,
        amount: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["amount", b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount"]) -> None: ...

global___QuerySupplyOfResponse = QuerySupplyOfResponse

@typing_extensions.final
class QueryTotalSupplyWithoutOffsetRequest(google.protobuf.message.Message):
    """QueryTotalSupplyWithoutOffsetRequest is the request type for the Query/TotalSupplyWithoutOffset RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request.

        Since: cosmos-sdk 0.43
        """
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___QueryTotalSupplyWithoutOffsetRequest = QueryTotalSupplyWithoutOffsetRequest

@typing_extensions.final
class QueryTotalSupplyWithoutOffsetResponse(google.protobuf.message.Message):
    """QueryTotalSupplyWithoutOffsetResponse is the response type for the Query/TotalSupplyWithoutOffset RPC
    method
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUPPLY_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def supply(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """supply is the supply of the coins"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response.

        Since: cosmos-sdk 0.43
        """
    def __init__(
        self,
        *,
        supply: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "supply", b"supply"]) -> None: ...

global___QueryTotalSupplyWithoutOffsetResponse = QueryTotalSupplyWithoutOffsetResponse

@typing_extensions.final
class QuerySupplyOfWithoutOffsetRequest(google.protobuf.message.Message):
    """QuerySupplyOfWithoutOffsetRequest is the request type for the Query/SupplyOfWithoutOffset RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    denom: builtins.str
    """denom is the coin denom to query balances for."""
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom"]) -> None: ...

global___QuerySupplyOfWithoutOffsetRequest = QuerySupplyOfWithoutOffsetRequest

@typing_extensions.final
class QuerySupplyOfWithoutOffsetResponse(google.protobuf.message.Message):
    """QuerySupplyOfWithoutOffsetResponse is the response type for the Query/SupplyOfWithoutOffset RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """amount is the supply of the coin."""
    def __init__(
        self,
        *,
        amount: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["amount", b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount"]) -> None: ...

global___QuerySupplyOfWithoutOffsetResponse = QuerySupplyOfWithoutOffsetResponse

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest defines the request type for querying x/bank parameters."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse defines the response type for querying x/bank parameters."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.bank.v1beta1.bank_pb2.Params: ...
    def __init__(
        self,
        *,
        params: cosmos.bank.v1beta1.bank_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse

@typing_extensions.final
class QueryDenomsMetadataRequest(google.protobuf.message.Message):
    """QueryDenomsMetadataRequest is the request type for the Query/DenomsMetadata RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___QueryDenomsMetadataRequest = QueryDenomsMetadataRequest

@typing_extensions.final
class QueryDenomsMetadataResponse(google.protobuf.message.Message):
    """QueryDenomsMetadataResponse is the response type for the Query/DenomsMetadata RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATAS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def metadatas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Metadata]:
        """metadata provides the client information for all the registered tokens."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        metadatas: collections.abc.Iterable[cosmos.bank.v1beta1.bank_pb2.Metadata] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadatas", b"metadatas", "pagination", b"pagination"]) -> None: ...

global___QueryDenomsMetadataResponse = QueryDenomsMetadataResponse

@typing_extensions.final
class QueryDenomMetadataRequest(google.protobuf.message.Message):
    """QueryDenomMetadataRequest is the request type for the Query/DenomMetadata RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    denom: builtins.str
    """denom is the coin denom to query the metadata for."""
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom"]) -> None: ...

global___QueryDenomMetadataRequest = QueryDenomMetadataRequest

@typing_extensions.final
class QueryDenomMetadataResponse(google.protobuf.message.Message):
    """QueryDenomMetadataResponse is the response type for the Query/DenomMetadata RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> cosmos.bank.v1beta1.bank_pb2.Metadata:
        """metadata describes and provides all the client information for the requested token."""
    def __init__(
        self,
        *,
        metadata: cosmos.bank.v1beta1.bank_pb2.Metadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> None: ...

global___QueryDenomMetadataResponse = QueryDenomMetadataResponse

@typing_extensions.final
class QueryBaseDenomRequest(google.protobuf.message.Message):
    """QueryBaseDenomRequest defines the request type for the BaseDenom gRPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    denom: builtins.str
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom"]) -> None: ...

global___QueryBaseDenomRequest = QueryBaseDenomRequest

@typing_extensions.final
class QueryBaseDenomResponse(google.protobuf.message.Message):
    """QueryBaseDenomResponse defines the response type for the BaseDenom gRPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_DENOM_FIELD_NUMBER: builtins.int
    base_denom: builtins.str
    def __init__(
        self,
        *,
        base_denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_denom", b"base_denom"]) -> None: ...

global___QueryBaseDenomResponse = QueryBaseDenomResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.slashing.v1beta1.slashing_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the slashing module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    SIGNING_INFOS_FIELD_NUMBER: builtins.int
    MISSED_BLOCKS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.slashing.v1beta1.slashing_pb2.Params:
        """params defines all the paramaters of related to deposit."""
    @property
    def signing_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SigningInfo]:
        """signing_infos represents a map between validator addresses and their
        signing infos.
        """
    @property
    def missed_blocks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorMissedBlocks]:
        """missed_blocks represents a map between validator addresses and their
        missed blocks.
        """
    def __init__(
        self,
        *,
        params: cosmos.slashing.v1beta1.slashing_pb2.Params | None = ...,
        signing_infos: collections.abc.Iterable[global___SigningInfo] | None = ...,
        missed_blocks: collections.abc.Iterable[global___ValidatorMissedBlocks] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["missed_blocks", b"missed_blocks", "params", b"params", "signing_infos", b"signing_infos"]) -> None: ...

global___GenesisState = GenesisState

@typing_extensions.final
class SigningInfo(google.protobuf.message.Message):
    """SigningInfo stores validator signing info of corresponding address."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_SIGNING_INFO_FIELD_NUMBER: builtins.int
    address: builtins.str
    """address is the validator address."""
    @property
    def validator_signing_info(self) -> cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo:
        """validator_signing_info represents the signing info of this validator."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        validator_signing_info: cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["validator_signing_info", b"validator_signing_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "validator_signing_info", b"validator_signing_info"]) -> None: ...

global___SigningInfo = SigningInfo

@typing_extensions.final
class ValidatorMissedBlocks(google.protobuf.message.Message):
    """ValidatorMissedBlocks contains array of missed blocks of corresponding
    address.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    MISSED_BLOCKS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """address is the validator address."""
    @property
    def missed_blocks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MissedBlock]:
        """missed_blocks is an array of missed blocks by the validator."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        missed_blocks: collections.abc.Iterable[global___MissedBlock] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "missed_blocks", b"missed_blocks"]) -> None: ...

global___ValidatorMissedBlocks = ValidatorMissedBlocks

@typing_extensions.final
class MissedBlock(google.protobuf.message.Message):
    """MissedBlock contains height and missed status as boolean."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    MISSED_FIELD_NUMBER: builtins.int
    index: builtins.int
    """index is the height at which the block was missed."""
    missed: builtins.bool
    """missed is the missed status."""
    def __init__(
        self,
        *,
        index: builtins.int = ...,
        missed: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["index", b"index", "missed", b"missed"]) -> None: ...

global___MissedBlock = MissedBlock



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/twap/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.twap.v1beta1 import twap_record_pb2 as osmosis_dot_twap_dot_v1beta1_dot_twap__record__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"osmosis/twap/v1beta1/genesis.proto\x12\x14osmosis.twap.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&osmosis/twap/v1beta1/twap_record.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1egoogle/protobuf/duration.proto\"\x96\x01\n\x06Params\x12\x1e\n\x16prune_epoch_identifier\x18\x01 \x01(\t\x12l\n\x1arecord_history_keep_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB-\xf2\xde\x1f!yaml:\"record_history_keep_period\"\x98\xdf\x1f\x01\xc8\xde\x1f\x00\"y\n\x0cGenesisState\x12\x35\n\x05twaps\x18\x01 \x03(\x0b\x32 .osmosis.twap.v1beta1.TwapRecordB\x04\xc8\xde\x1f\x00\x12\x32\n\x06params\x18\x02 \x01(\x0b\x32\x1c.osmosis.twap.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x42\x32Z0github.com/osmosis-labs/osmosis/v14/x/twap/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.twap.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/osmosis-labs/osmosis/v14/x/twap/types'
  _PARAMS.fields_by_name['record_history_keep_period']._options = None
  _PARAMS.fields_by_name['record_history_keep_period']._serialized_options = b'\362\336\037!yaml:\"record_history_keep_period\"\230\337\037\001\310\336\037\000'
  _GENESISSTATE.fields_by_name['twaps']._options = None
  _GENESISSTATE.fields_by_name['twaps']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _PARAMS._serialized_start=209
  _PARAMS._serialized_end=359
  _GENESISSTATE._serialized_start=361
  _GENESISSTATE._serialized_end=482
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PoolParams(google.protobuf.message.Message):
    """PoolParams defined the parameters that will be managed by the pool
    governance in the future. This params are not managed by the chain
    governance. Instead they will be managed by the token holders of the pool.
    The pool's token holders are specified in future_pool_governor.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SWAP_FEE_FIELD_NUMBER: builtins.int
    EXIT_FEE_FIELD_NUMBER: builtins.int
    swap_fee: builtins.str
    exit_fee: builtins.str
    def __init__(
        self,
        *,
        swap_fee: builtins.str = ...,
        exit_fee: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exit_fee", b"exit_fee", "swap_fee", b"swap_fee"]) -> None: ...

global___PoolParams = PoolParams

@typing_extensions.final
class Pool(google.protobuf.message.Message):
    """Pool is the stableswap Pool struct"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POOL_PARAMS_FIELD_NUMBER: builtins.int
    FUTURE_POOL_GOVERNOR_FIELD_NUMBER: builtins.int
    TOTAL_SHARES_FIELD_NUMBER: builtins.int
    POOL_LIQUIDITY_FIELD_NUMBER: builtins.int
    SCALING_FACTORS_FIELD_NUMBER: builtins.int
    SCALING_FACTOR_CONTROLLER_FIELD_NUMBER: builtins.int
    address: builtins.str
    id: builtins.int
    @property
    def pool_params(self) -> global___PoolParams: ...
    future_pool_governor: builtins.str
    """This string specifies who will govern the pool in the future.
    Valid forms of this are:
    {token name},{duration}
    {duration}
    where {token name} if specified is the token which determines the
    governor, and if not specified is the LP token for this pool.duration is
    a time specified as 0w,1w,2w, etc. which specifies how long the token
    would need to be locked up to count in governance. 0w means no lockup.
    """
    @property
    def total_shares(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """sum of all LP shares"""
    @property
    def pool_liquidity(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """assets in the pool"""
    @property
    def scaling_factors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """for calculation amognst assets with different precisions"""
    scaling_factor_controller: builtins.str
    """scaling_factor_controller is the address can adjust pool scaling factors"""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        id: builtins.int = ...,
        pool_params: global___PoolParams | None = ...,
        future_pool_governor: builtins.str = ...,
        total_shares: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
        pool_liquidity: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        scaling_factors: collections.abc.Iterable[builtins.int] | None = ...,
        scaling_factor_controller: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pool_params", b"pool_params", "total_shares", b"total_shares"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "future_pool_governor", b"future_pool_governor", "id", b"id", "pool_liquidity", b"pool_liquidity", "pool_params", b"pool_params", "scaling_factor_controller", b"scaling_factor_controller", "scaling_factors", b"scaling_factors", "total_shares", b"total_shares"]) -> None: ...

global___Pool = Pool



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PubKey(google.protobuf.message.Message):
    """PubKey defines a secp256k1 public key
    Key is the compressed form of the pubkey. The first byte depends is a 0x02 byte
    if the y-coordinate is the lexicographically largest of the two associated with
    the x-coordinate. Otherwise the first byte is a 0x03.
    This prefix is followed with the x-coordinate.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___PubKey = PubKey

@typing_extensions.final
class PrivKey(google.protobuf.message.Message):
    """PrivKey defines a secp256k1 private key."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___PrivKey = PrivKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.gamm.v1beta1.tx_pb2

class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    JoinPool: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.tx_pb2.MsgJoinPool,
        osmosis.gamm.v1beta1.tx_pb2.MsgJoinPoolResponse,
    ]
    ExitPool: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.tx_pb2.MsgExitPool,
        osmosis.gamm.v1beta1.tx_pb2.MsgExitPoolResponse,
    ]
    SwapExactAmountIn: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.tx_pb2.MsgSwapExactAmountIn,
        osmosis.gamm.v1beta1.tx_pb2.MsgSwapExactAmountInResponse,
    ]
    SwapExactAmountOut: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.tx_pb2.MsgSwapExactAmountOut,
        osmosis.gamm.v1beta1.tx_pb2.MsgSwapExactAmountOutResponse,
    ]
    JoinSwapExternAmountIn: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.tx_pb2.MsgJoinSwapExternAmountIn,
        osmosis.gamm.v1beta1.tx_pb2.MsgJoinSwapExternAmountInResponse,
    ]
    JoinSwapShareAmountOut: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.tx_pb2.MsgJoinSwapShareAmountOut,
        osmosis.gamm.v1beta1.tx_pb2.MsgJoinSwapShareAmountOutResponse,
    ]
    ExitSwapExternAmountOut: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.tx_pb2.MsgExitSwapExternAmountOut,
        osmosis.gamm.v1beta1.tx_pb2.MsgExitSwapExternAmountOutResponse,
    ]
    ExitSwapShareAmountIn: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.tx_pb2.MsgExitSwapShareAmountIn,
        osmosis.gamm.v1beta1.tx_pb2.MsgExitSwapShareAmountInResponse,
    ]

class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def JoinPool(
        self,
        request: osmosis.gamm.v1beta1.tx_pb2.MsgJoinPool,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.tx_pb2.MsgJoinPoolResponse: ...
    @abc.abstractmethod
    def ExitPool(
        self,
        request: osmosis.gamm.v1beta1.tx_pb2.MsgExitPool,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.tx_pb2.MsgExitPoolResponse: ...
    @abc.abstractmethod
    def SwapExactAmountIn(
        self,
        request: osmosis.gamm.v1beta1.tx_pb2.MsgSwapExactAmountIn,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.tx_pb2.MsgSwapExactAmountInResponse: ...
    @abc.abstractmethod
    def SwapExactAmountOut(
        self,
        request: osmosis.gamm.v1beta1.tx_pb2.MsgSwapExactAmountOut,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.tx_pb2.MsgSwapExactAmountOutResponse: ...
    @abc.abstractmethod
    def JoinSwapExternAmountIn(
        self,
        request: osmosis.gamm.v1beta1.tx_pb2.MsgJoinSwapExternAmountIn,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.tx_pb2.MsgJoinSwapExternAmountInResponse: ...
    @abc.abstractmethod
    def JoinSwapShareAmountOut(
        self,
        request: osmosis.gamm.v1beta1.tx_pb2.MsgJoinSwapShareAmountOut,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.tx_pb2.MsgJoinSwapShareAmountOutResponse: ...
    @abc.abstractmethod
    def ExitSwapExternAmountOut(
        self,
        request: osmosis.gamm.v1beta1.tx_pb2.MsgExitSwapExternAmountOut,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.tx_pb2.MsgExitSwapExternAmountOutResponse: ...
    @abc.abstractmethod
    def ExitSwapShareAmountIn(
        self,
        request: osmosis.gamm.v1beta1.tx_pb2.MsgExitSwapShareAmountIn,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.tx_pb2.MsgExitSwapShareAmountInResponse: ...

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/gamm/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dosmosis/gamm/v1beta1/tx.proto\x12\x14osmosis.gamm.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x90\x02\n\x0bMsgJoinPool\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x62\n\x10share_out_amount\x18\x03 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"pool_amount_out\"\xc8\xde\x1f\x00\x12U\n\rtoken_in_maxs\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB#\xf2\xde\x1f\x1byaml:\"token_in_max_amounts\"\xc8\xde\x1f\x00\"\xc0\x01\n\x13MsgJoinPoolResponse\x12\x63\n\x10share_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"share_out_amount\"\xc8\xde\x1f\x00\x12\x44\n\x08token_in\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\"\x91\x02\n\x0bMsgExitPool\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x61\n\x0fshare_in_amount\x18\x03 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"share_in_amount\"\xc8\xde\x1f\x00\x12W\n\x0etoken_out_mins\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB$\xf2\xde\x1f\x1cyaml:\"token_out_min_amounts\"\xc8\xde\x1f\x00\"]\n\x13MsgExitPoolResponse\x12\x46\n\ttoken_out\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\"m\n\x11SwapAmountInRoute\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x33\n\x0ftoken_out_denom\x18\x02 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"token_out_denom\"\"\xab\x02\n\x14MsgSwapExactAmountIn\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12=\n\x06routes\x18\x02 \x03(\x0b\x32\'.osmosis.gamm.v1beta1.SwapAmountInRouteB\x04\xc8\xde\x1f\x00\x12\x44\n\x08token_in\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\x12k\n\x14token_out_min_amount\x18\x04 \x01(\tBM\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1byaml:\"token_out_min_amount\"\xc8\xde\x1f\x00\"\x83\x01\n\x1cMsgSwapExactAmountInResponse\x12\x63\n\x10token_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"token_out_amount\"\xc8\xde\x1f\x00\"m\n\x12SwapAmountOutRoute\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x32\n\x0etoken_in_denom\x18\x02 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"token_out_denom\"\"\xad\x02\n\x15MsgSwapExactAmountOut\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12>\n\x06routes\x18\x02 \x03(\x0b\x32(.osmosis.gamm.v1beta1.SwapAmountOutRouteB\x04\xc8\xde\x1f\x00\x12i\n\x13token_in_max_amount\x18\x03 \x01(\tBL\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:\"token_in_max_amount\"\xc8\xde\x1f\x00\x12\x46\n\ttoken_out\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\"\x82\x01\n\x1dMsgSwapExactAmountOutResponse\x12\x61\n\x0ftoken_in_amount\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"token_in_amount\"\xc8\xde\x1f\x00\"\x96\x02\n\x19MsgJoinSwapExternAmountIn\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x44\n\x08token_in\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\x12k\n\x14share_out_min_amount\x18\x04 \x01(\tBM\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1byaml:\"share_out_min_amount\"\xc8\xde\x1f\x00\"\x88\x01\n!MsgJoinSwapExternAmountInResponse\x12\x63\n\x10share_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"share_out_amount\"\xc8\xde\x1f\x00\"\xe6\x02\n\x19MsgJoinSwapShareAmountOut\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x31\n\x0etoken_in_denom\x18\x03 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"token_in_denom\"\x12\x63\n\x10share_out_amount\x18\x04 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"share_out_amount\"\xc8\xde\x1f\x00\x12i\n\x13token_in_max_amount\x18\x05 \x01(\tBL\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:\"token_in_max_amount\"\xc8\xde\x1f\x00\"\x86\x01\n!MsgJoinSwapShareAmountOutResponse\x12\x61\n\x0ftoken_in_amount\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"token_in_amount\"\xc8\xde\x1f\x00\"\xe7\x02\n\x18MsgExitSwapShareAmountIn\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x33\n\x0ftoken_out_denom\x18\x03 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"token_out_denom\"\x12\x61\n\x0fshare_in_amount\x18\x04 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"share_in_amount\"\xc8\xde\x1f\x00\x12k\n\x14token_out_min_amount\x18\x05 \x01(\tBM\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1byaml:\"token_out_min_amount\"\xc8\xde\x1f\x00\"\x87\x01\n MsgExitSwapShareAmountInResponse\x12\x63\n\x10token_out_amount\x18\x01 \x01(\tBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"token_out_amount\"\xc8\xde\x1f\x00\"\x97\x02\n\x1aMsgExitSwapExternAmountOut\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x46\n\ttoken_out\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\x12i\n\x13share_in_max_amount\x18\x04 \x01(\tBL\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x1ayaml:\"share_in_max_amount\"\xc8\xde\x1f\x00\"\x87\x01\n\"MsgExitSwapExternAmountOutResponse\x12\x61\n\x0fshare_in_amount\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"share_in_amount\"\xc8\xde\x1f\x00\x32\xb9\x07\n\x03Msg\x12X\n\x08JoinPool\x12!.osmosis.gamm.v1beta1.MsgJoinPool\x1a).osmosis.gamm.v1beta1.MsgJoinPoolResponse\x12X\n\x08\x45xitPool\x12!.osmosis.gamm.v1beta1.MsgExitPool\x1a).osmosis.gamm.v1beta1.MsgExitPoolResponse\x12s\n\x11SwapExactAmountIn\x12*.osmosis.gamm.v1beta1.MsgSwapExactAmountIn\x1a\x32.osmosis.gamm.v1beta1.MsgSwapExactAmountInResponse\x12v\n\x12SwapExactAmountOut\x12+.osmosis.gamm.v1beta1.MsgSwapExactAmountOut\x1a\x33.osmosis.gamm.v1beta1.MsgSwapExactAmountOutResponse\x12\x82\x01\n\x16JoinSwapExternAmountIn\x12/.osmosis.gamm.v1beta1.MsgJoinSwapExternAmountIn\x1a\x37.osmosis.gamm.v1beta1.MsgJoinSwapExternAmountInResponse\x12\x82\x01\n\x16JoinSwapShareAmountOut\x12/.osmosis.gamm.v1beta1.MsgJoinSwapShareAmountOut\x1a\x37.osmosis.gamm.v1beta1.MsgJoinSwapShareAmountOutResponse\x12\x85\x01\n\x17\x45xitSwapExternAmountOut\x12\x30.osmosis.gamm.v1beta1.MsgExitSwapExternAmountOut\x1a\x38.osmosis.gamm.v1beta1.MsgExitSwapExternAmountOutResponse\x12\x7f\n\x15\x45xitSwapShareAmountIn\x12..osmosis.gamm.v1beta1.MsgExitSwapShareAmountIn\x1a\x36.osmosis.gamm.v1beta1.MsgExitSwapShareAmountInResponseB2Z0github.com/osmosis-labs/osmosis/v14/x/gamm/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.gamm.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/osmosis-labs/osmosis/v14/x/gamm/types'
  _MSGJOINPOOL.fields_by_name['sender']._options = None
  _MSGJOINPOOL.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGJOINPOOL.fields_by_name['pool_id']._options = None
  _MSGJOINPOOL.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGJOINPOOL.fields_by_name['share_out_amount']._options = None
  _MSGJOINPOOL.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"pool_amount_out\"\310\336\037\000'
  _MSGJOINPOOL.fields_by_name['token_in_maxs']._options = None
  _MSGJOINPOOL.fields_by_name['token_in_maxs']._serialized_options = b'\362\336\037\033yaml:\"token_in_max_amounts\"\310\336\037\000'
  _MSGJOINPOOLRESPONSE.fields_by_name['share_out_amount']._options = None
  _MSGJOINPOOLRESPONSE.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"share_out_amount\"\310\336\037\000'
  _MSGJOINPOOLRESPONSE.fields_by_name['token_in']._options = None
  _MSGJOINPOOLRESPONSE.fields_by_name['token_in']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _MSGEXITPOOL.fields_by_name['sender']._options = None
  _MSGEXITPOOL.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGEXITPOOL.fields_by_name['pool_id']._options = None
  _MSGEXITPOOL.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGEXITPOOL.fields_by_name['share_in_amount']._options = None
  _MSGEXITPOOL.fields_by_name['share_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"share_in_amount\"\310\336\037\000'
  _MSGEXITPOOL.fields_by_name['token_out_mins']._options = None
  _MSGEXITPOOL.fields_by_name['token_out_mins']._serialized_options = b'\362\336\037\034yaml:\"token_out_min_amounts\"\310\336\037\000'
  _MSGEXITPOOLRESPONSE.fields_by_name['token_out']._options = None
  _MSGEXITPOOLRESPONSE.fields_by_name['token_out']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _SWAPAMOUNTINROUTE.fields_by_name['pool_id']._options = None
  _SWAPAMOUNTINROUTE.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _SWAPAMOUNTINROUTE.fields_by_name['token_out_denom']._options = None
  _SWAPAMOUNTINROUTE.fields_by_name['token_out_denom']._serialized_options = b'\362\336\037\026yaml:\"token_out_denom\"'
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['sender']._options = None
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['routes']._options = None
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['routes']._serialized_options = b'\310\336\037\000'
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['token_in']._options = None
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['token_in']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['token_out_min_amount']._options = None
  _MSGSWAPEXACTAMOUNTIN.fields_by_name['token_out_min_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\033yaml:\"token_out_min_amount\"\310\336\037\000'
  _MSGSWAPEXACTAMOUNTINRESPONSE.fields_by_name['token_out_amount']._options = None
  _MSGSWAPEXACTAMOUNTINRESPONSE.fields_by_name['token_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"token_out_amount\"\310\336\037\000'
  _SWAPAMOUNTOUTROUTE.fields_by_name['pool_id']._options = None
  _SWAPAMOUNTOUTROUTE.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _SWAPAMOUNTOUTROUTE.fields_by_name['token_in_denom']._options = None
  _SWAPAMOUNTOUTROUTE.fields_by_name['token_in_denom']._serialized_options = b'\362\336\037\026yaml:\"token_out_denom\"'
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['sender']._options = None
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['routes']._options = None
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['routes']._serialized_options = b'\310\336\037\000'
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['token_in_max_amount']._options = None
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['token_in_max_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\032yaml:\"token_in_max_amount\"\310\336\037\000'
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['token_out']._options = None
  _MSGSWAPEXACTAMOUNTOUT.fields_by_name['token_out']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _MSGSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._options = None
  _MSGSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"token_in_amount\"\310\336\037\000'
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['sender']._options = None
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['pool_id']._options = None
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['token_in']._options = None
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['token_in']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['share_out_min_amount']._options = None
  _MSGJOINSWAPEXTERNAMOUNTIN.fields_by_name['share_out_min_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\033yaml:\"share_out_min_amount\"\310\336\037\000'
  _MSGJOINSWAPEXTERNAMOUNTINRESPONSE.fields_by_name['share_out_amount']._options = None
  _MSGJOINSWAPEXTERNAMOUNTINRESPONSE.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"share_out_amount\"\310\336\037\000'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['sender']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['pool_id']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['token_in_denom']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['token_in_denom']._serialized_options = b'\362\336\037\025yaml:\"token_in_denom\"'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['share_out_amount']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['share_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"share_out_amount\"\310\336\037\000'
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['token_in_max_amount']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUT.fields_by_name['token_in_max_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\032yaml:\"token_in_max_amount\"\310\336\037\000'
  _MSGJOINSWAPSHAREAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._options = None
  _MSGJOINSWAPSHAREAMOUNTOUTRESPONSE.fields_by_name['token_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"token_in_amount\"\310\336\037\000'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['sender']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['pool_id']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['token_out_denom']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['token_out_denom']._serialized_options = b'\362\336\037\026yaml:\"token_out_denom\"'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['share_in_amount']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['share_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"share_in_amount\"\310\336\037\000'
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['token_out_min_amount']._options = None
  _MSGEXITSWAPSHAREAMOUNTIN.fields_by_name['token_out_min_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\033yaml:\"token_out_min_amount\"\310\336\037\000'
  _MSGEXITSWAPSHAREAMOUNTINRESPONSE.fields_by_name['token_out_amount']._options = None
  _MSGEXITSWAPSHAREAMOUNTINRESPONSE.fields_by_name['token_out_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"token_out_amount\"\310\336\037\000'
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['sender']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['pool_id']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['token_out']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['token_out']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['share_in_max_amount']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUT.fields_by_name['share_in_max_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\032yaml:\"share_in_max_amount\"\310\336\037\000'
  _MSGEXITSWAPEXTERNAMOUNTOUTRESPONSE.fields_by_name['share_in_amount']._options = None
  _MSGEXITSWAPEXTERNAMOUNTOUTRESPONSE.fields_by_name['share_in_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"share_in_amount\"\310\336\037\000'
  _MSGJOINPOOL._serialized_start=110
  _MSGJOINPOOL._serialized_end=382
  _MSGJOINPOOLRESPONSE._serialized_start=385
  _MSGJOINPOOLRESPONSE._serialized_end=577
  _MSGEXITPOOL._serialized_start=580
  _MSGEXITPOOL._serialized_end=853
  _MSGEXITPOOLRESPONSE._serialized_start=855
  _MSGEXITPOOLRESPONSE._serialized_end=948
  _SWAPAMOUNTINROUTE._serialized_start=950
  _SWAPAMOUNTINROUTE._serialized_end=1059
  _MSGSWAPEXACTAMOUNTIN._serialized_start=1062
  _MSGSWAPEXACTAMOUNTIN._serialized_end=1361
  _MSGSWAPEXACTAMOUNTINRESPONSE._serialized_start=1364
  _MSGSWAPEXACTAMOUNTINRESPONSE._serialized_end=1495
  _SWAPAMOUNTOUTROUTE._serialized_start=1497
  _SWAPAMOUNTOUTROUTE._serialized_end=1606
  _MSGSWAPEXACTAMOUNTOUT._serialized_start=1609
  _MSGSWAPEXACTAMOUNTOUT._serialized_end=1910
  _MSGSWAPEXACTAMOUNTOUTRESPONSE._serialized_start=1913
  _MSGSWAPEXACTAMOUNTOUTRESPONSE._serialized_end=2043
  _MSGJOINSWAPEXTERNAMOUNTIN._serialized_start=2046
  _MSGJOINSWAPEXTERNAMOUNTIN._serialized_end=2324
  _MSGJOINSWAPEXTERNAMOUNTINRESPONSE._serialized_start=2327
  _MSGJOINSWAPEXTERNAMOUNTINRESPONSE._serialized_end=2463
  _MSGJOINSWAPSHAREAMOUNTOUT._serialized_start=2466
  _MSGJOINSWAPSHAREAMOUNTOUT._serialized_end=2824
  _MSGJOINSWAPSHAREAMOUNTOUTRESPONSE._serialized_start=2827
  _MSGJOINSWAPSHAREAMOUNTOUTRESPONSE._serialized_end=2961
  _MSGEXITSWAPSHAREAMOUNTIN._serialized_start=2964
  _MSGEXITSWAPSHAREAMOUNTIN._serialized_end=3323
  _MSGEXITSWAPSHAREAMOUNTINRESPONSE._serialized_start=3326
  _MSGEXITSWAPSHAREAMOUNTINRESPONSE._serialized_end=3461
  _MSGEXITSWAPEXTERNAMOUNTOUT._serialized_start=3464
  _MSGEXITSWAPEXTERNAMOUNTOUT._serialized_end=3743
  _MSGEXITSWAPEXTERNAMOUNTOUTRESPONSE._serialized_start=3746
  _MSGEXITSWAPEXTERNAMOUNTOUTRESPONSE._serialized_end=3881
  _MSG._serialized_start=3884
  _MSG._serialized_end=4837
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.auth.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Accounts: grpc.UnaryUnaryMultiCallable[
        cosmos.auth.v1beta1.query_pb2.QueryAccountsRequest,
        cosmos.auth.v1beta1.query_pb2.QueryAccountsResponse,
    ]
    """Accounts returns all the existing accounts

    Since: cosmos-sdk 0.43
    """
    Account: grpc.UnaryUnaryMultiCallable[
        cosmos.auth.v1beta1.query_pb2.QueryAccountRequest,
        cosmos.auth.v1beta1.query_pb2.QueryAccountResponse,
    ]
    """Account returns account details based on address."""
    Params: grpc.UnaryUnaryMultiCallable[
        cosmos.auth.v1beta1.query_pb2.QueryParamsRequest,
        cosmos.auth.v1beta1.query_pb2.QueryParamsResponse,
    ]
    """Params queries all parameters."""
    ModuleAccounts: grpc.UnaryUnaryMultiCallable[
        cosmos.auth.v1beta1.query_pb2.QueryModuleAccountsRequest,
        cosmos.auth.v1beta1.query_pb2.QueryModuleAccountsResponse,
    ]
    """ModuleAccounts returns all the existing module accounts."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Accounts(
        self,
        request: cosmos.auth.v1beta1.query_pb2.QueryAccountsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.auth.v1beta1.query_pb2.QueryAccountsResponse:
        """Accounts returns all the existing accounts

        Since: cosmos-sdk 0.43
        """
    @abc.abstractmethod
    def Account(
        self,
        request: cosmos.auth.v1beta1.query_pb2.QueryAccountRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.auth.v1beta1.query_pb2.QueryAccountResponse:
        """Account returns account details based on address."""
    @abc.abstractmethod
    def Params(
        self,
        request: cosmos.auth.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.auth.v1beta1.query_pb2.QueryParamsResponse:
        """Params queries all parameters."""
    @abc.abstractmethod
    def ModuleAccounts(
        self,
        request: cosmos.auth.v1beta1.query_pb2.QueryModuleAccountsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.auth.v1beta1.query_pb2.QueryModuleAccountsResponse:
        """ModuleAccounts returns all the existing module accounts."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.twap.v1beta1.twap_record_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params holds parameters for the twap module"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRUNE_EPOCH_IDENTIFIER_FIELD_NUMBER: builtins.int
    RECORD_HISTORY_KEEP_PERIOD_FIELD_NUMBER: builtins.int
    prune_epoch_identifier: builtins.str
    @property
    def record_history_keep_period(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        prune_epoch_identifier: builtins.str = ...,
        record_history_keep_period: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["record_history_keep_period", b"record_history_keep_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prune_epoch_identifier", b"prune_epoch_identifier", "record_history_keep_period", b"record_history_keep_period"]) -> None: ...

global___Params = Params

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the twap module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TWAPS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def twaps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.twap.v1beta1.twap_record_pb2.TwapRecord]:
        """twaps is the collection of all twap records."""
    @property
    def params(self) -> global___Params:
        """params is the container of twap parameters."""
    def __init__(
        self,
        *,
        twaps: collections.abc.Iterable[osmosis.twap.v1beta1.twap_record_pb2.TwapRecord] | None = ...,
        params: global___Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params", "twaps", b"twaps"]) -> None: ...

global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.evidence.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Evidence: grpc.UnaryUnaryMultiCallable[
        cosmos.evidence.v1beta1.query_pb2.QueryEvidenceRequest,
        cosmos.evidence.v1beta1.query_pb2.QueryEvidenceResponse,
    ]
    """Evidence queries evidence based on evidence hash."""
    AllEvidence: grpc.UnaryUnaryMultiCallable[
        cosmos.evidence.v1beta1.query_pb2.QueryAllEvidenceRequest,
        cosmos.evidence.v1beta1.query_pb2.QueryAllEvidenceResponse,
    ]
    """AllEvidence queries all evidence."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Evidence(
        self,
        request: cosmos.evidence.v1beta1.query_pb2.QueryEvidenceRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.evidence.v1beta1.query_pb2.QueryEvidenceResponse:
        """Evidence queries evidence based on evidence hash."""
    @abc.abstractmethod
    def AllEvidence(
        self,
        request: cosmos.evidence.v1beta1.query_pb2.QueryAllEvidenceRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.evidence.v1beta1.query_pb2.QueryAllEvidenceResponse:
        """AllEvidence queries all evidence."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/lockup/lock.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19osmosis/lockup/lock.proto\x12\x0eosmosis.lockup\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xc0\x02\n\nPeriodLock\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x1f\n\x05owner\x18\x02 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12^\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\x12I\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1b\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"end_time\"\x12Z\n\x05\x63oins\x18\x05 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\xee\x01\n\x0eQueryCondition\x12\x36\n\x0flock_query_type\x18\x01 \x01(\x0e\x32\x1d.osmosis.lockup.LockQueryType\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12H\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\x98\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"duration\"\x12K\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\"\xeb\x01\n\rSyntheticLock\x12\x1a\n\x12underlying_lock_id\x18\x01 \x01(\x04\x12\x13\n\x0bsynth_denom\x18\x02 \x01(\t\x12I\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1b\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"end_time\"\x12^\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"*1\n\rLockQueryType\x12\x0e\n\nByDuration\x10\x00\x12\n\n\x06\x42yTime\x10\x01\x1a\x04\x88\xa3\x1e\x00\x42\x34Z2github.com/osmosis-labs/osmosis/v14/x/lockup/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.lockup.lock_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/osmosis-labs/osmosis/v14/x/lockup/types'
  _LOCKQUERYTYPE._options = None
  _LOCKQUERYTYPE._serialized_options = b'\210\243\036\000'
  _PERIODLOCK.fields_by_name['owner']._options = None
  _PERIODLOCK.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _PERIODLOCK.fields_by_name['duration']._options = None
  _PERIODLOCK.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
  _PERIODLOCK.fields_by_name['end_time']._options = None
  _PERIODLOCK.fields_by_name['end_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\017yaml:\"end_time\"'
  _PERIODLOCK.fields_by_name['coins']._options = None
  _PERIODLOCK.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYCONDITION.fields_by_name['duration']._options = None
  _QUERYCONDITION.fields_by_name['duration']._serialized_options = b'\230\337\037\001\310\336\037\000\362\336\037\017yaml:\"duration\"'
  _QUERYCONDITION.fields_by_name['timestamp']._options = None
  _QUERYCONDITION.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _SYNTHETICLOCK.fields_by_name['end_time']._options = None
  _SYNTHETICLOCK.fields_by_name['end_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\017yaml:\"end_time\"'
  _SYNTHETICLOCK.fields_by_name['duration']._options = None
  _SYNTHETICLOCK.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
  _LOCKQUERYTYPE._serialized_start=966
  _LOCKQUERYTYPE._serialized_end=1015
  _PERIODLOCK._serialized_start=165
  _PERIODLOCK._serialized_end=485
  _QUERYCONDITION._serialized_start=488
  _QUERYCONDITION._serialized_end=726
  _SYNTHETICLOCK._serialized_start=729
  _SYNTHETICLOCK._serialized_end=964
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgSubmitProposal(google.protobuf.message.Message):
    """MsgSubmitProposal defines an sdk.Msg type that supports submitting arbitrary
    proposal Content.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    INITIAL_DEPOSIT_FIELD_NUMBER: builtins.int
    PROPOSER_FIELD_NUMBER: builtins.int
    IS_EXPEDITED_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def initial_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    proposer: builtins.str
    is_expedited: builtins.bool
    def __init__(
        self,
        *,
        content: google.protobuf.any_pb2.Any | None = ...,
        initial_deposit: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        proposer: builtins.str = ...,
        is_expedited: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "initial_deposit", b"initial_deposit", "is_expedited", b"is_expedited", "proposer", b"proposer"]) -> None: ...

global___MsgSubmitProposal = MsgSubmitProposal

@typing_extensions.final
class MsgSubmitProposalResponse(google.protobuf.message.Message):
    """MsgSubmitProposalResponse defines the Msg/SubmitProposal response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal_id", b"proposal_id"]) -> None: ...

global___MsgSubmitProposalResponse = MsgSubmitProposalResponse

@typing_extensions.final
class MsgVote(google.protobuf.message.Message):
    """MsgVote defines a message to cast a vote."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    voter: builtins.str
    option: cosmos.gov.v1beta1.gov_pb2.VoteOption.ValueType
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        voter: builtins.str = ...,
        option: cosmos.gov.v1beta1.gov_pb2.VoteOption.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["option", b"option", "proposal_id", b"proposal_id", "voter", b"voter"]) -> None: ...

global___MsgVote = MsgVote

@typing_extensions.final
class MsgVoteResponse(google.protobuf.message.Message):
    """MsgVoteResponse defines the Msg/Vote response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgVoteResponse = MsgVoteResponse

@typing_extensions.final
class MsgVoteWeighted(google.protobuf.message.Message):
    """MsgVoteWeighted defines a message to cast a vote.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    voter: builtins.str
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.WeightedVoteOption]: ...
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        voter: builtins.str = ...,
        options: collections.abc.Iterable[cosmos.gov.v1beta1.gov_pb2.WeightedVoteOption] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options", "proposal_id", b"proposal_id", "voter", b"voter"]) -> None: ...

global___MsgVoteWeighted = MsgVoteWeighted

@typing_extensions.final
class MsgVoteWeightedResponse(google.protobuf.message.Message):
    """MsgVoteWeightedResponse defines the Msg/VoteWeighted response type.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgVoteWeightedResponse = MsgVoteWeightedResponse

@typing_extensions.final
class MsgDeposit(google.protobuf.message.Message):
    """MsgDeposit defines a message to submit a deposit to an existing proposal."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    depositor: builtins.str
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        depositor: builtins.str = ...,
        amount: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "depositor", b"depositor", "proposal_id", b"proposal_id"]) -> None: ...

global___MsgDeposit = MsgDeposit

@typing_extensions.final
class MsgDepositResponse(google.protobuf.message.Message):
    """MsgDepositResponse defines the Msg/Deposit response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgDepositResponse = MsgDepositResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/query.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a cosmos/authz/v1beta1/authz.proto\"\x88\x01\n\x12QueryGrantsRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x14\n\x0cmsg_type_url\x18\x03 \x01(\t\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x7f\n\x13QueryGrantsResponse\x12+\n\x06grants\x18\x01 \x03(\x0b\x32\x1b.cosmos.authz.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x8d\x01\n\x05Query\x12\x83\x01\n\x06Grants\x12(.cosmos.authz.v1beta1.QueryGrantsRequest\x1a).cosmos.authz.v1beta1.QueryGrantsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/authz/v1beta1/grantsB&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
  _QUERY.methods_by_name['Grants']._options = None
  _QUERY.methods_by_name['Grants']._serialized_options = b'\202\323\344\223\002\036\022\034/cosmos/authz/v1beta1/grants'
  _QUERYGRANTSREQUEST._serialized_start=167
  _QUERYGRANTSREQUEST._serialized_end=303
  _QUERYGRANTSRESPONSE._serialized_start=305
  _QUERYGRANTSRESPONSE._serialized_end=432
  _QUERY._serialized_start=435
  _QUERY._serialized_end=576
# @@protoc_insertion_point(module_scope)
